Creates an enumeration type using regular function call syntax. The resulting type only
accepts atomic vectors whose elements all belong to the declared set of
allowed values.
Usage
Enum(...)
Value
A new sicher_type that checks all values belong to the enum.
Arguments
...
Allowed scalar values or a single atomic vector of allowed values.